//+------------------------------------------------------------------+
//|                                                       Scooby.mq4 |
//|              Copyright  2009, Mark Johnson. All rights reserved |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+

#property show_inputs

//+------------------------------------------------------------------+
//| expert External variables                                        |
//+------------------------------------------------------------------+

extern int    magic = 1801;
extern string key   = "XE8KxqdKctnixYJ";
extern int    rsi   = 3;

//+------------------------------------------------------------------+
//| expert Internal variables                                        |
//+------------------------------------------------------------------+

string pairs[] = {"AUDJPY","AUDUSD","CHFJPY","EURAUD",
                  "EURCHF","EURGBP","EURJPY","EURUSD",
                  "GBPUSD","USDCAD","USDCHF","USDJPY"};
string author  = "Copyright 2009, Mark Johnson. All rights reserved.";
string suffix;
bool   found;
bool   news;
bool   allowed;
double balance;
double price;
int    order;

//+------------------------------------------------------------------+
//| expert Initialization function                                   |
//+------------------------------------------------------------------+

int init()
  {

    balance = AccountBalance();
    suffix  = StringSubstr(Symbol(),6,StringLen(Symbol())-6);

    for(int a = 0; a < ArraySize(pairs); a++)
      {
        pairs[a] = pairs[a] + suffix;
      }
      
    Comment("\nWaiting for tick update...");

    return(0);
    
  }
  
//+------------------------------------------------------------------+
//| expert Deinitialization function                                 |
//+------------------------------------------------------------------+

int deinit()
  {

    Comment("");
    
    return(0);

  }
  
//+------------------------------------------------------------------+
//| expert Start function                                            |
//+------------------------------------------------------------------+

int start()
  {
    
    double Lots = NormalizeDouble(balance/50000,1);
    double Min  = MarketInfo(Symbol(),MODE_MINLOT);
    double Max  = MarketInfo(Symbol(),MODE_MAXLOT);

    if(Lots < Min) Lots = Min;
    if(Lots > Max) Lots = Max;
    
    Comment("\n",author,"\n\n","Lots = ",DoubleToStr(Lots,2));

    for(int c = 0; c < ArraySize(pairs); c++)
      {

        double SMA1 = iMA(pairs[c],60,020,0,MODE_EMA,PRICE_CLOSE,0);
        double SMA2 = iMA(pairs[c],60,034,0,MODE_EMA,PRICE_CLOSE,0);
        double SMA3 = iMA(pairs[c],60,100,0,MODE_SMA,PRICE_CLOSE,0);

        double LTF = iRSI(pairs[c],15,rsi,PRICE_CLOSE,0);
        double HTF = iRSI(pairs[c],60,rsi,PRICE_CLOSE,0);

        if(HTF > 0)
          {
            if(HTF < 30) TradeClose(pairs[c],OP_SELL);
            if(HTF > 70) TradeClose(pairs[c],OP_BUY);
          }

        if(TimeDayOfWeek(TimeLocal()) == 5 && TimeHour(TimeLocal()) >= 12)
          {
            break;
          }
          
        if(OrdersTotal() < 8 && LTF < 20 && HTF < 20 && SMA1 > SMA2 && SMA2 > SMA3)
          {
            if(TradeExist(pairs[c]) == false) SendOrder(pairs[c],OP_BUY,Lots);
          }
          
        if(OrdersTotal() < 8 && LTF > 80 && HTF > 80 && SMA1 < SMA2 && SMA2 < SMA3)
          {
            if(TradeExist(pairs[c]) == false) SendOrder(pairs[c],OP_SELL,Lots);
          }
          
      }
      
    return(0);

  }

//+------------------------------------------------------------------+
//| expert TradeClose function                                       |
//+------------------------------------------------------------------+

void TradeClose(string symbol, int dir)
  {

    for(int b = OrdersTotal(); b >= 0; b--)
      {
        if(OrderSelect(b,SELECT_BY_POS,MODE_TRADES) == true)
          {
            if(OrderSymbol() == symbol && OrderType() == dir && OrderMagicNumber() == magic)
              {
                order = -1;
                while(order < 0)
                  {
                    RefreshRates();
                    order = OrderClose(OrderTicket(),OrderLots(),OrderClosePrice(),3,CLR_NONE);
                    Sleep(10);
                  }
              }
          }
      }

  }

//+------------------------------------------------------------------+
//| expert TradeExists function                                      |
//+------------------------------------------------------------------+

bool TradeExist(string symbol)
  {

    found = false;

    for(int d = 0; d <= OrdersTotal(); d++)
      {
        if(OrderSelect(d,SELECT_BY_POS,MODE_TRADES) == true)
          {
            if(OrderSymbol() == symbol && OrderMagicNumber() == magic)
              {
                found = true;
              }
          }
      }

    return(found);

  }

//+------------------------------------------------------------------+
//| expert SendOrder function                                        |
//+------------------------------------------------------------------+  

void SendOrder(string symbol, int dir, double lots)
  {
    
    price = 0;
    order = -1;
    
    if(dir == OP_BUY)
      {
        while(order < 0)
          {
            RefreshRates();
            price = MarketInfo(symbol,MODE_ASK);
            order = OrderSend(symbol,dir,lots,price,3,0,0,key,magic,0,CLR_NONE);
            Sleep(10);
          }
      }
      
    if(dir == OP_SELL)
      {
        while(order < 0)
          {
            RefreshRates();
            price = MarketInfo(symbol,MODE_BID);
            order = OrderSend(symbol,dir,lots,price,3,0,0,key,magic,0,CLR_NONE);
            Sleep(10);
          }
      }
  
  }

//+------------------------------------------------------------------+
//| expert News function                                             |
//+------------------------------------------------------------------+  

bool NewsExist(string symbol)
  {
  
    news = false;
    
    int minutesSincePrevEvent =
      iCustom(NULL, 0, "Economic News", symbol, true, false, false, true, true, 1, 0);

    int minutesUntilNextEvent =
      iCustom(NULL, 0, "Economic News", symbol, true, false, false, true, true, 1, 1);

    if((minutesUntilNextEvent <= 45) || 
       (minutesSincePrevEvent <= 15))
      {
        news = true;
      }
      
    return(news);

  }
   